@@ -6,6 +6,7 @@ from qfunction import q_sin,q_exp,q_cos,radian,limit
 import numpy as np
 from numpy import sqrt,array
 from math import atan
+import numpy as np
 ############ quantum equations #############
 def q_rho(u,q=1,cpx=False,israd=True):
 	u = radian(u) if(not israd) else u
@@ -23,8 +24,14 @@ def q_psi(theta,gamma,q=1,israd=True):
     theta = radian(theta) if(not israd) else theta
     theta = 1j*theta/2
     gamma = gamma/2
-    gamma = gamma if abs(gamma) <= 2*np.pi else np.nan
-    theta = theta if abs(theta) <= np.pi else np.nan
+    #print(gamma)
+    #gamma = np.array(gamma)
+    if(type(gamma)==np.ndarray):
+        gamma[np.abs(gamma) > np.pi] = np.nan
+        theta[np.abs(theta) > 2*np.pi] = np.nan
+    else:
+        gamma = np.nan if np.abs(gamma)>np.pi else gamma
+        theta = np.nan if np.abs(theta)>2*np.pi else theta
     coluna0 = [q_exp(-theta,q).real*q_cos(gamma,q).real]
     coluna1 = [q_exp(theta,q).real*q_sin(gamma,q).real]
     return array([coluna0,coluna1])
